==> haskell-hspec-api-2.11.3-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-api
version:              2.11.3
visibility:           public
id:                   hspec-api-2.11.3-4KHuB4pFbjV5qdJLIe7AUr
key:                  hspec-api-2.11.3-4KHuB4pFbjV5qdJLIe7AUr
license:              MIT
copyright:            (c) 2022-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
stability:            stable
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package provides a stable API that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  12903dad935d3e56a4e5b705772f5291
exposed:              True
exposed-modules:
    Test.Hspec.Api.Format.V1 Test.Hspec.Api.Format.V2
    Test.Hspec.Api.Formatters.V1 Test.Hspec.Api.Formatters.V2
    Test.Hspec.Api.Formatters.V3

hidden-modules:       Test.Hspec.Api.Format.V1.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-api-2.11.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-api-2.11.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-api-2.11.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-api
hs-libraries:         HShspec-api-2.11.3-4KHuB4pFbjV5qdJLIe7AUr
depends:
    base-4.17.2.1 hspec-core-2.11.3-AJUV3eYoh6bD6Fh6jWbr6D
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-api/html/hspec-api.haddock
haddock-html:         /usr/share/doc/haskell-hspec-api/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-api-2.11.3-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-api.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-api
version:              2.11.3
visibility:           public
id:                   hspec-api-2.11.3-L9tRhBQPRqh2eKA30SDR0w
key:                  hspec-api-2.11.3-L9tRhBQPRqh2eKA30SDR0w
license:              MIT
copyright:            (c) 2022-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
stability:            stable
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package provides a stable API that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  4fbc55b007801b7ea91077d9387a023b
exposed:              True
exposed-modules:
    Test.Hspec.Api.Format.V1 Test.Hspec.Api.Format.V2
    Test.Hspec.Api.Formatters.V1 Test.Hspec.Api.Formatters.V2
    Test.Hspec.Api.Formatters.V3

hidden-modules:       Test.Hspec.Api.Format.V1.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-api-2.11.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-api-2.11.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-api-2.11.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-api
hs-libraries:         HShspec-api-2.11.3-L9tRhBQPRqh2eKA30SDR0w
depends:
    base-4.17.2.1 hspec-core-2.11.3-6W8u2DdWzE85dCBIDgnJ5A
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-api/html/hspec-api.haddock
haddock-html:         /usr/share/doc/haskell-hspec-api/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
